==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebDropdownItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebDropdownItemComponentEventArgsDescription } from "./WebDropdownItemComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebDropdownItemComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemComponentEventArgsDescriptionMetadata.a == null) {
                WebDropdownItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemComponentEventArgsDescriptionMetadata.c(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebDropdownItemComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            WebDropdownItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownItemComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:WebDropdownItem");
        }
        static d(a) {
            WebDropdownItemComponentEventArgsDescriptionMetadata.b(a);
            a.ad("WebDropdownItemComponentEventArgs", () => new WebDropdownItemComponentEventArgsDescription());
            a.ac("WebDropdownItemComponentEventArgs", WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebDropdownItemComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemComponentEventArgsDescriptionMetadata, 'WebDropdownItemComponentEventArgsDescriptionMetadata');
    WebDropdownItemComponentEventArgsDescriptionMetadata.a = null;
    return WebDropdownItemComponentEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebDropdownItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebDropdownItemComponentEventArgsDescription } from "./WebDropdownItemComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebDropdownItemComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownItemComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownItemComponentEventArgsDescriptionMetadata.a == null) {
                WebDropdownItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownItemComponentEventArgsDescriptionMetadata.c(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebDropdownItemComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
            WebDropdownItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownItemComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebDropdownItem");
        }
        static d(a) {
            WebDropdownItemComponentEventArgsDescriptionMetadata.b(a);
            a.ae("WebDropdownItemComponentEventArgs", () => new WebDropdownItemComponentEventArgsDescription());
            a.ad("WebDropdownItemComponentEventArgs", WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebDropdownItemComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownItemComponentEventArgsDescriptionMetadata, 'WebDropdownItemComponentEventArgsDescriptionMetadata');
    WebDropdownItemComponentEventArgsDescriptionMetadata.a = null;
    return WebDropdownItemComponentEventArgsDescriptionMetadata;
})();
